changeset 20713:2469d78a1d8b

Consistently use 'filename' rather than 'file name' throughout code base. * bootstrap, configure.ac, basics.txi, gui.txi, io.txi, mkoctfile.1, __init_qt__.cc, dialog.cc, files-dock-widget.cc, find-files-dialog.cc, file-editor-tab.cc, file-editor-tab.h, file-editor.cc, shortcut-manager.cc, debug.cc, dirfns.cc, dlmread.cc, file-io.cc, input.cc, load-path.h, load-save.cc, symtab.h, sysdep.cc, utils.cc, variables.cc, zfstream.h, oct-parse.in.yy, dir-ops.cc, file-ops.h, cmd-hist.cc, cmd-hist.h, octave_tmp_file_name.m, uigetfile.m, uiputfile.m, imshow.m, imageIO.m, dlmwrite.m, importdata.m, copyfile.m, edit.m, mkoctfile.m, movefile.m, open.m, perl.m, python.m, run.m, tmpnam.m, unpack.m, fminsearch.m, configure_make.m, print.m, __print_parse_opts__.m, test.m, main.in.cc, mkoctfile.in.cc, module.mk: Consistently use 'filename' rather than 'file name' throughout code base.
author Rik <rik@octave.org>
date Wed, 18 Nov 2015 15:48:27 -0800
parents 4a25c398ffa2
children 7b6d8c19dab0
files bootstrap configure.ac doc/interpreter/basics.txi doc/interpreter/gui.txi doc/interpreter/io.txi doc/interpreter/mkoctfile.1 libgui/graphics/__init_qt__.cc libgui/src/dialog.cc libgui/src/files-dock-widget.cc libgui/src/find-files-dialog.cc libgui/src/m-editor/file-editor-tab.cc libgui/src/m-editor/file-editor-tab.h libgui/src/m-editor/file-editor.cc libgui/src/shortcut-manager.cc libinterp/corefcn/debug.cc libinterp/corefcn/dirfns.cc libinterp/corefcn/dlmread.cc libinterp/corefcn/file-io.cc libinterp/corefcn/input.cc libinterp/corefcn/load-path.h libinterp/corefcn/load-save.cc libinterp/corefcn/symtab.h libinterp/corefcn/sysdep.cc libinterp/corefcn/utils.cc libinterp/corefcn/variables.cc libinterp/corefcn/zfstream.h libinterp/parse-tree/oct-parse.in.yy liboctave/system/dir-ops.cc liboctave/system/file-ops.h liboctave/util/cmd-hist.cc liboctave/util/cmd-hist.h scripts/deprecated/octave_tmp_file_name.m scripts/gui/uigetfile.m scripts/gui/uiputfile.m scripts/image/imshow.m scripts/image/private/imageIO.m scripts/io/dlmwrite.m scripts/io/importdata.m scripts/miscellaneous/copyfile.m scripts/miscellaneous/edit.m scripts/miscellaneous/mkoctfile.m scripts/miscellaneous/movefile.m scripts/miscellaneous/open.m scripts/miscellaneous/perl.m scripts/miscellaneous/python.m scripts/miscellaneous/run.m scripts/miscellaneous/tmpnam.m scripts/miscellaneous/unpack.m scripts/optimization/fminsearch.m scripts/pkg/private/configure_make.m scripts/plot/util/print.m scripts/plot/util/private/__print_parse_opts__.m scripts/testfun/test.m src/main.in.cc src/mkoctfile.in.cc src/module.mk
diffstat 56 files changed, 108 insertions(+), 108 deletions(-) [+]
line wrap: on
line diff
--- a/bootstrap	Wed Nov 18 15:44:33 2015 -0500
+++ b/bootstrap	Wed Nov 18 15:48:27 2015 -0800
@@ -32,7 +32,7 @@
 nl='
 '
 
-# Ensure file names are sorted consistently across platforms.
+# Ensure filenames are sorted consistently across platforms.
 LC_ALL=C
 export LC_ALL
 
--- a/configure.ac	Wed Nov 18 15:44:33 2015 -0500
+++ b/configure.ac	Wed Nov 18 15:48:27 2015 -0800
@@ -2693,7 +2693,7 @@
     ;;
   esac
 
-  ## Determine which library file name to search for.
+  ## Determine which library filename to search for.
   case $host_os in
     darwin*)
       jvmlib=libjvm.dylib
--- a/doc/interpreter/basics.txi	Wed Nov 18 15:44:33 2015 -0500
+++ b/doc/interpreter/basics.txi	Wed Nov 18 15:48:27 2015 -0800
@@ -984,7 +984,7 @@
 interpreter to be run, and an optional initial command line argument to
 pass to that interpreter.  The operating system then runs the
 interpreter with the given argument and the full argument list of the
-executed program.  The first argument in the list is the full file name
+executed program.  The first argument in the list is the full filename
 of the Octave executable.  The rest of the argument list will either be
 options to Octave, or data files, or both.  The @samp{-qf} options are
 usually specified in stand-alone Octave programs to prevent them from
--- a/doc/interpreter/gui.txi	Wed Nov 18 15:44:33 2015 -0500
+++ b/doc/interpreter/gui.txi	Wed Nov 18 15:48:27 2015 -0800
@@ -50,7 +50,7 @@
 
 Simple dialog menus are available for choosing directories or files.  They
 return a string variable which can then be used with any command requiring
-a file name.
+a filename.
 
 @DOCSTRING(uigetdir)
 
--- a/doc/interpreter/io.txi	Wed Nov 18 15:44:33 2015 -0500
+++ b/doc/interpreter/io.txi	Wed Nov 18 15:48:27 2015 -0800
@@ -269,7 +269,7 @@
 argument lists for some of the input functions are slightly different,
 however, because Octave has no way of passing arguments by reference.
 
-In the following, @var{file} refers to a file name and @code{fid} refers
+In the following, @var{file} refers to a filename and @code{fid} refers
 to an integer file number, as returned by @code{fopen}.
 
 There are three files that are always available.  Although these files
--- a/doc/interpreter/mkoctfile.1	Wed Nov 18 15:44:33 2015 -0500
+++ b/doc/interpreter/mkoctfile.1	Wed Nov 18 15:48:27 2015 -0800
@@ -88,7 +88,7 @@
 Create a MEX file.  Set the default output extension to \fB.mex\fP.
 .TP
 .B \-o \fIfile\fP\fR,\fB \-\-output \fIfile\fP
-Output file name.  Default extension is \fB.oct\fP (or \fB.mex\fP if \-\-mex is
+Output filename.  Default extension is \fB.oct\fP (or \fB.mex\fP if \-\-mex is
 specified) unless linking a stand-alone executable.
 .TP
 .B \-p \fIVAR\fP\fR,\fB \-\-print \fIVAR\fP
--- a/libgui/graphics/__init_qt__.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libgui/graphics/__init_qt__.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -190,7 +190,7 @@
   // Expected arguments:
   //   args(0) : File filter as a cell array {ext1, name1; ext2, name2; ...}
   //   args(1) : Dialog title
-  //   args(2) : Default file name
+  //   args(2) : Default filename
   //   args(3) : Dialog position [ignored]
   //   args(4) : Multiselection "on"/"off"
   //   args(5) : Default directory
@@ -272,7 +272,7 @@
   // Expected arguments:
   //   args(0) : File filter as a cell array {ext1, name1; ext2, name2; ...}
   //   args(1) : Dialog title
-  //   args(2) : Default file name
+  //   args(2) : Default filename
   //   args(3) : Dialog position [ignored]
   //   args(4) : Tag [ignored]
   //   args(5) : Default directory
--- a/libgui/src/dialog.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libgui/src/dialog.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -522,7 +522,7 @@
       path = directory ().absolutePath ();
     }
 
-  // Matlab expects just the file name, whereas the file dialog gave us
+  // Matlab expects just the filename, whereas the file dialog gave us
   // full path names, so fix it.
 
   for (int i = 0; i < string_result.size (); i++)
--- a/libgui/src/files-dock-widget.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libgui/src/files-dock-widget.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -793,7 +793,7 @@
 
   _navigation_tool_bar->setIconSize (QSize (icon_size,icon_size));
 
-  // file names are always shown, other columns can be hidden by settings
+  // filenames are always shown, other columns can be hidden by settings
   for (int i = 0; i < 3; i++)
      _file_tree_view->setColumnHidden (i + 1, ! settings->value (
                                   _columns_shown_keys.at (i),false).toBool ());
--- a/libgui/src/find-files-dialog.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libgui/src/find-files-dialog.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -159,7 +159,7 @@
            this,          SLOT (close ()));
 
   // name options
-  QGroupBox * name_group = new QGroupBox (tr ("File name/location"));
+  QGroupBox * name_group = new QGroupBox (tr ("Filename/location"));
   QGridLayout * name_layout = new QGridLayout;
   name_group->setLayout (name_layout);
 
--- a/libgui/src/m-editor/file-editor-tab.h	Wed Nov 18 15:44:33 2015 -0500
+++ b/libgui/src/m-editor/file-editor-tab.h	Wed Nov 18 15:48:27 2015 -0800
@@ -70,7 +70,7 @@
   // Change to a different editor tab by identifier tag.
   void change_editor_state (const QWidget *ID);
 
-  // Simply transmit file name.
+  // Simply transmit filename.
   void file_name_query (const QWidget *ID);
 
   void set_focus (const QWidget *ID);
--- a/libgui/src/m-editor/file-editor.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libgui/src/m-editor/file-editor.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -73,11 +73,11 @@
   // Save open files for restoring in next session; this only is possible
   QSettings *settings = resource_manager::get_settings ();
 
-  // Have all file editor tabs signal what their file names are.
+  // Have all file editor tabs signal what their filenames are.
   editor_tab_map.clear ();
   emit fetab_file_name_query (0);
 
-  // save file names (even if last session will not be restored next time)
+  // save filenames (even if last session will not be restored next time)
   QStringList fetFileNames;
   for (editor_tab_map_const_iterator p = editor_tab_map.begin ();
        p != editor_tab_map.end (); p++)
@@ -344,7 +344,7 @@
     }
   else
     {
-      // Have all file editor tabs signal what their file names are.
+      // Have all file editor tabs signal what their filenames are.
       editor_tab_map.clear ();
       emit fetab_file_name_query (0);
 
@@ -498,7 +498,7 @@
 file_editor::check_conflict_save (const QString& saveFileName,
                                   bool remove_on_success)
 {
-  // Have all file editor tabs signal what their file names are.
+  // Have all file editor tabs signal what their filenames are.
   editor_tab_map.clear ();
   emit fetab_file_name_query (0);
 
@@ -572,7 +572,7 @@
 {
   if (! file.isEmpty ())
     {
-      // Have all file editor tabs signal what their file names are.
+      // Have all file editor tabs signal what their filenames are.
       editor_tab_map.clear ();
       emit fetab_file_name_query (0);
 
@@ -888,7 +888,7 @@
 file_editor::handle_mru_add_file (const QString& file_name)
 {
   if (_mru_files.count () && _mru_files.at (0) == file_name)
-    return;  // the first entry is already the actual file name
+    return;  // the first entry is already the actual filename
 
   _mru_files.removeAll (file_name);
   _mru_files.prepend (file_name);
--- a/libgui/src/shortcut-manager.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libgui/src/shortcut-manager.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -673,7 +673,7 @@
         return false;
     }
 
-  // get the file name to read or write the shortcuts,
+  // get the filename to read or write the shortcuts,
   // the default extension is .osc (octave shortcuts)
   if (action != OSC_DEFAULT)
     {
--- a/libinterp/corefcn/debug.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libinterp/corefcn/debug.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -1262,7 +1262,7 @@
 With optional argument @var{n}, omit the @var{n} innermost stack frames.\n\
 \n\
 Although accepted, the argument @var{-completenames} is silently ignored.\n\
-Octave always returns absolute file names.\n\
+Octave always returns absolute filenames.\n\
 \n\
 The arguments @var{n} and @var{-completenames} can be both specified in any\n\
 order.\n\
--- a/libinterp/corefcn/dirfns.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libinterp/corefcn/dirfns.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -511,7 +511,7 @@
        "-*- texinfo -*-\n\
 @deftypefn {Built-in Function} {} glob (@var{pattern})\n\
 Given an array of pattern strings (as a char array or a cell array) in\n\
-@var{pattern}, return a cell array of file names that match any of\n\
+@var{pattern}, return a cell array of filenames that match any of\n\
 them, or an empty cell array if no patterns match.\n\
 \n\
 The pattern strings are interpreted as filename globbing patterns (as they\n\
@@ -531,7 +531,7 @@
 @end table\n\
 \n\
 Tilde expansion is performed on each of the patterns before looking for\n\
-matching file names.  For example:\n\
+matching filenames.  For example:\n\
 \n\
 @example\n\
 ls\n\
--- a/libinterp/corefcn/dlmread.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libinterp/corefcn/dlmread.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -180,7 +180,7 @@
 lowest alphabetical index @qcode{'A'} refers to the first column.  The\n\
 lowest row index is 1.\n\
 \n\
-@var{file} should be a file name or file id given by @code{fopen}.  In the\n\
+@var{file} should be a filename or file id given by @code{fopen}.  In the\n\
 latter case, the file is read until end of file is reached.\n\
 \n\
 The @qcode{\"emptyvalue\"} option may be used to specify the value used to\n\
@@ -213,7 +213,7 @@
 
   if (args(0).is_string ())
     {
-      // File name.
+      // Filename.
       std::string fname (args(0).string_value ());
 
       std::string tname = file_ops::tilde_expand (fname);
--- a/libinterp/corefcn/file-io.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libinterp/corefcn/file-io.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -538,7 +538,7 @@
 
   fid = -1;
 
-  std::string name = tc_name.xstring_value ("%s: file name must be a string", fcn);
+  std::string name = tc_name.xstring_value ("%s: filename must be a string", fcn);
   std::string mode = tc_mode.xstring_value ("%s: file mode must be a string", fcn);
   std::string arch = tc_arch.xstring_value ("%s: architecture type must be a string", fcn);
 
@@ -1846,7 +1846,7 @@
 @deftypefn  {Built-in Function} {@var{fname} =} tempname ()\n\
 @deftypefnx {Built-in Function} {@var{fname} =} tempname (@var{dir})\n\
 @deftypefnx {Built-in Function} {@var{fname} =} tempname (@var{dir}, @var{prefix})\n\
-Return a unique temporary file name as a string.\n\
+Return a unique temporary filename as a string.\n\
 \n\
 If @var{prefix} is omitted, a value of @qcode{\"oct-\"} is used.\n\
 \n\
--- a/libinterp/corefcn/input.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libinterp/corefcn/input.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -328,7 +328,7 @@
   return command_editor::get_input_stream ();
 }
 
-// FIXME: make this generate file names when appropriate.
+// FIXME: make this generate filenames when appropriate.
 
 static string_vector
 generate_possible_completions (const std::string& text, std::string& prefix,
--- a/libinterp/corefcn/load-path.h	Wed Nov 18 15:44:33 2015 -0500
+++ b/libinterp/corefcn/load-path.h	Wed Nov 18 15:48:27 2015 -0800
@@ -446,10 +446,10 @@
   // private files (those found in the special "private" subdirectory)
   // in each directory.
   //
-  // Second, a map from file names (the union of all "public" files for all
+  // Second, a map from filenames (the union of all "public" files for all
   // directories, but without filename extensions) to a list of
   // corresponding information (directory name and file types).  This
-  // way, we can quickly find shadowed file names and look up all
+  // way, we can quickly find shadowed filenames and look up all
   // overloaded functions (in the "@" directories used to implement
   // classes).
 
--- a/libinterp/corefcn/load-save.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libinterp/corefcn/load-save.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -1375,7 +1375,7 @@
 {
   if (Vcrash_dumps_octave_core)
     {
-      // FIXME: should choose better file name?
+      // FIXME: should choose better filename?
 
       const char *fname = Voctave_core_file_name.c_str ();
 
--- a/libinterp/corefcn/symtab.h	Wed Nov 18 15:44:33 2015 -0500
+++ b/libinterp/corefcn/symtab.h	Wed Nov 18 15:48:27 2015 -0800
@@ -2345,8 +2345,8 @@
   // The scope of this symbol table.
   scope_id my_scope;
 
-  // Name for this table (usually the file name of the function
-  // corresponding to the scope);
+  // Name for this table
+  // (usually the filename of the function corresponding to the scope);
   std::string table_name;
 
   // Map from symbol names to symbol info.
--- a/libinterp/corefcn/sysdep.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libinterp/corefcn/sysdep.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -195,7 +195,7 @@
 
   if (args.length () == 1)
     {
-      std::string file = args(0).xstring_value ("__open_with_system_app__: argument must be a file name");
+      std::string file = args(0).xstring_value ("__open_with_system_app__: argument must be a filename");
 
 #if defined (__WIN32__) && ! defined (_POSIX_VERSION)
       HINSTANCE status = ShellExecute (0, 0, file.c_str (), 0, 0,
--- a/libinterp/corefcn/utils.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libinterp/corefcn/utils.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -995,7 +995,7 @@
 
   if (args.length () == 1)
     {
-      std::string nm = args(0).xstring_value ("make_absolute_filename: FILE argument must be a file name");
+      std::string nm = args(0).xstring_value ("make_absolute_filename: FILE argument must be a filename");
 
       retval = octave_env::make_absolute (nm);
     }
--- a/libinterp/corefcn/variables.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libinterp/corefcn/variables.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -530,7 +530,7 @@
 @var{name} is a variable.\n\
 \n\
 @item 2\n\
-@var{name} is an absolute file name, an ordinary file in Octave's\n\
+@var{name} is an absolute filename, an ordinary file in Octave's\n\
 @code{path}, or (after appending @samp{.m}) a function file in Octave's\n\
 @code{path}.\n\
 \n\
@@ -637,13 +637,13 @@
 %!assert (exist ("print_usage", "file"), 2)
 %!assert (exist ("print_usage", "dir"), 0)
 
-## Don't search path for rooted relative file names
+## Don't search path for rooted relative filenames
 %!assert (exist ("plot.m", "file"), 2);
 %!assert (exist ("./plot.m", "file"), 0);
 %!assert (exist ("./%nonexistentfile%", "file"), 0);
 %!assert (exist ("%nonexistentfile%", "file"), 0);
 
-## Don't search path for absolute file names
+## Don't search path for absolute filenames
 %!test
 %! tname = tempname (pwd ());
 %! unwind_protect
@@ -1629,7 +1629,7 @@
           // implement this option there so that the variables are never
           // stored at all.
           if (i == argc - 1)
-            error ("whos: -file argument must be followed by a file name");
+            error ("whos: -file argument must be followed by a filename");
           else
             {
               std::string nm = argv[i + 1];
--- a/libinterp/corefcn/zfstream.h	Wed Nov 18 15:44:33 2015 -0500
+++ b/libinterp/corefcn/zfstream.h	Wed Nov 18 15:48:27 2015 -0800
@@ -83,7 +83,7 @@
 
   /**
    *  @brief  Open gzipped file.
-   *  @param  name  File name.
+   *  @param  name  Filename.
    *  @param  mode  Open mode flags.
    *  @return  @c this on success, NULL on failure.
   */
@@ -286,7 +286,7 @@
 
   /**
    *  @brief  Construct stream on gzipped file to be opened.
-   *  @param  name  File name.
+   *  @param  name  Filename.
    *  @param  mode  Open mode flags (forced to contain ios::in).
   */
   explicit
@@ -318,7 +318,7 @@
 
   /**
    *  @brief  Open gzipped file.
-   *  @param  name  File name.
+   *  @param  name  Filename.
    *  @param  mode  Open mode flags (forced to contain ios::in).
    *
    *  Stream will be in state good() if file opens successfully;
@@ -375,7 +375,7 @@
 
   /**
    *  @brief  Construct stream on gzipped file to be opened.
-   *  @param  name  File name.
+   *  @param  name  Filename.
    *  @param  mode  Open mode flags (forced to contain ios::out).
   */
   explicit
@@ -407,7 +407,7 @@
 
   /**
    *  @brief  Open gzipped file.
-   *  @param  name  File name.
+   *  @param  name  Filename.
    *  @param  mode  Open mode flags (forced to contain ios::out).
    *
    *  Stream will be in state good() if file opens successfully;
--- a/libinterp/parse-tree/oct-parse.in.yy	Wed Nov 18 15:44:33 2015 -0500
+++ b/libinterp/parse-tree/oct-parse.in.yy	Wed Nov 18 15:48:27 2015 -0800
@@ -3129,7 +3129,7 @@
   {
     // FIXME -- should lexer.fcn_file_name already be
     // preprocessed when we get here?  It seems to only be a
-    // problem with relative file names.
+    // problem with relative filenames.
 
     std::string nm = lexer.fcn_file_name;
 
@@ -3142,7 +3142,7 @@
       {
         warning_with_id
           ("Octave:function-name-clash",
-           "function name '%s' does not agree with function file name '%s'",
+           "function name '%s' does not agree with function filename '%s'",
            id_name.c_str (), lexer.fcn_file_full_name.c_str ());
 
         id_name = nm;
@@ -3355,7 +3355,7 @@
     nm = lexer.fcn_file_name.substr (pos+1);
 
   if (nm != cls_name)
-    bison_error ("invalid classdef definition, the class name must match the file name");
+    bison_error ("invalid classdef definition, the class name must match the filename");
   else if (end_token_ok (end_tok, token::classdef_end))
     {
       octave_comment_list *tc = lexer.comment_buf.get_comment ();
@@ -4304,7 +4304,7 @@
 @deftypefnx {Built-in Function} {} autoload (@dots{}, \"remove\")\n\
 Define @var{function} to autoload from @var{file}.\n\
 \n\
-The second argument, @var{file}, should be an absolute file name or a file\n\
+The second argument, @var{file}, should be an absolute filename or a file\n\
 name in the same directory as the function or script from which the autoload\n\
 command was run.  @var{file} @emph{should not} depend on the Octave load\n\
 path.\n\
@@ -4395,7 +4395,7 @@
             }
           if (! found)
             warning_with_id ("Octave:autoload-relative-file-name",
-                             "autoload: '%s' is not an absolute file name",
+                             "autoload: '%s' is not an absolute filename",
                              nm.c_str ());
         }
       if (nargin == 2)
@@ -4529,10 +4529,10 @@
 When called from outside an m-file return the empty string.\n\
 \n\
 Given the argument @qcode{\"fullpath\"}, include the directory part of the\n\
-file name, but not the extension.\n\
+filename, but not the extension.\n\
 \n\
 Given the argument @qcode{\"fullpathext\"}, include the directory part of\n\
-the file name and the extension.\n\
+the filename and the extension.\n\
 @end deftypefn")
 {
   octave_value retval;
@@ -4599,7 +4599,7 @@
 
   if (nargin == 1 || nargin == 2)
     {
-      std::string file_name = args(0).xstring_value ("source: expecting file name as argument");
+      std::string file_name = args(0).xstring_value ("source: expecting filename as argument");
 
       std::string context;
 
@@ -5192,7 +5192,7 @@
 
   if (nargin == 1 || nargin == 2)
     {
-      std::string file = args(0).xstring_value ("__parse_file__: expecting file name as argument");
+      std::string file = args(0).xstring_value ("__parse_file__: expecting filename as argument");
 
       std::string full_file = octave_env::make_absolute (file);
 
--- a/liboctave/system/dir-ops.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/liboctave/system/dir-ops.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -61,7 +61,7 @@
         errmsg = gnulib::strerror (errno);
     }
   else
-    errmsg = "dir_entry::open: empty file name";
+    errmsg = "dir_entry::open: empty filename";
 
   return ! fail;
 }
--- a/liboctave/system/file-ops.h	Wed Nov 18 15:44:33 2015 -0500
+++ b/liboctave/system/file-ops.h	Wed Nov 18 15:48:27 2015 -0800
@@ -82,7 +82,7 @@
 
   static std::string concat (const std::string&, const std::string&);
 
-  // Return the tail member of a file name.
+  // Return the tail member of a filename.
   static std::string tail (const std::string& path)
   {
     size_t ipos = path.find_last_of (dir_sep_chars ());
--- a/liboctave/util/cmd-hist.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/liboctave/util/cmd-hist.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -317,7 +317,7 @@
         }
     }
   else
-    error ("gnu_history::read: missing file name");
+    error ("gnu_history::read: missing filename");
 }
 
 void
@@ -347,7 +347,7 @@
         }
     }
   else
-    error ("gnu_history::read_range: missing file name");
+    error ("gnu_history::read_range: missing filename");
 }
 
 void
@@ -372,7 +372,7 @@
             }
         }
       else
-        error ("gnu_history::write: missing file name");
+        error ("gnu_history::write: missing filename");
     }
 }
 
@@ -419,7 +419,7 @@
                   lines_this_session = 0;
                 }
               else
-                error ("gnu_history::append: missing file name");
+                error ("gnu_history::append: missing filename");
             }
         }
     }
@@ -438,7 +438,7 @@
       if (! f.empty ())
         ::octave_history_truncate_file (f.c_str (), n);
       else
-        error ("gnu_history::truncate_file: missing file name");
+        error ("gnu_history::truncate_file: missing filename");
     }
 }
 
@@ -492,7 +492,7 @@
           do_write (f.c_str ());
         }
       else
-        error ("gnu_history::clean_up_and_save: missing file name");
+        error ("gnu_history::clean_up_and_save: missing filename");
     }
 }
 
@@ -920,14 +920,14 @@
 command_history::do_read (const std::string& f, bool)
 {
   if (f.empty ())
-    error ("command_history::read: missing file name");
+    error ("command_history::read: missing filename");
 }
 
 void
 command_history::do_read_range (const std::string& f, int, int, bool)
 {
   if (f.empty ())
-    error ("command_history::read_range: missing file name");
+    error ("command_history::read_range: missing filename");
 }
 
 void
@@ -941,7 +941,7 @@
         f = xfile;
 
       if (f.empty ())
-        error ("command_history::write: missing file name");
+        error ("command_history::write: missing filename");
     }
 }
 
@@ -962,7 +962,7 @@
                 f = xfile;
 
               if (f.empty ())
-                error ("command_history::append: missing file name");
+                error ("command_history::append: missing filename");
             }
         }
     }
@@ -979,7 +979,7 @@
         f = xfile;
 
       if (f.empty ())
-        error ("command_history::truncate_file: missing file name");
+        error ("command_history::truncate_file: missing filename");
     }
 }
 
@@ -1011,7 +1011,7 @@
         f = xfile;
 
       if (f.empty ())
-        error ("command_history::clean_up_and_save: missing file name");
+        error ("command_history::clean_up_and_save: missing filename");
     }
 }
 
--- a/liboctave/util/cmd-hist.h	Wed Nov 18 15:44:33 2015 -0500
+++ b/liboctave/util/cmd-hist.h	Wed Nov 18 15:48:27 2015 -0800
@@ -205,7 +205,7 @@
 
   void error (const std::string&) const;
 
-  // TRUE means we have initialized the history file name and number of
+  // TRUE means we have initialized the history filename and number of
   // lines to save.
   bool initialized;
 
--- a/scripts/deprecated/octave_tmp_file_name.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/deprecated/octave_tmp_file_name.m	Wed Nov 18 15:48:27 2015 -0800
@@ -24,7 +24,7 @@
 ## @code{octave_tmp_file_name} is deprecated and will be removed in Octave
 ## version 4.4.  Use @code{tempname} for equivalent functionality.
 ##
-## Return a unique temporary file name as a string.
+## Return a unique temporary filename as a string.
 ##
 ## If @var{prefix} is omitted, a value of @qcode{"oct-"} is used.
 ## If @var{dir} is also omitted, the default directory for temporary files
--- a/scripts/gui/uigetfile.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/gui/uigetfile.m	Wed Nov 18 15:48:27 2015 -0800
@@ -75,7 +75,7 @@
   ## Preset default values
   outargs = {cell(0, 2),         # File Filter
              "Open File",        # Dialog Title
-             "",                 # Default file name
+             "",                 # Default filename
              [240, 120],         # Dialog Position (pixel x/y)
              "off",              # MultiSelect on/off
              pwd};               # Default directory
--- a/scripts/gui/uiputfile.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/gui/uiputfile.m	Wed Nov 18 15:48:27 2015 -0800
@@ -65,7 +65,7 @@
   ## Preset default values
   outargs = {cell(0, 2),     # File Filter
              "Save File",    # Dialog Title
-             "",             # Default file name
+             "",             # Default filename
              [240, 120],     # Dialog Position (pixel x/y)
              "create",
              pwd};           # Default directory
--- a/scripts/image/imshow.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/image/imshow.m	Wed Nov 18 15:48:27 2015 -0800
@@ -35,7 +35,7 @@
 ## If @var{map} is a valid color map, the image will be shown as an indexed
 ## image using the supplied color map.
 ##
-## If a file name is given instead of an image, the file will be read and shown.
+## If a filename is given instead of an image, the file will be read and shown.
 ##
 ## If given, the parameter @var{string_param1} has value @var{value1}.
 ## @var{string_param1} can be any of the following:
--- a/scripts/image/private/imageIO.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/image/private/imageIO.m	Wed Nov 18 15:48:27 2015 -0800
@@ -96,7 +96,7 @@
       endif
     endif
 
-    ## try extension from file name
+    ## try extension from filename
     if (isempty (foo))
       [~, ~, ext] = fileparts (fn);
       if (! isempty (ext))
--- a/scripts/io/dlmwrite.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/io/dlmwrite.m	Wed Nov 18 15:48:27 2015 -0800
@@ -24,7 +24,7 @@
 ## @deftypefnx {Function File} {} dlmwrite (@var{fid}, @dots{})
 ## Write the matrix @var{M} to the named file using delimiters.
 ##
-## @var{file} should be a file name or writable file ID given by @code{fopen}.
+## @var{file} should be a filename or writable file ID given by @code{fopen}.
 ##
 ## The parameter @var{delim} specifies the delimiter to use to separate values
 ## on a row.
--- a/scripts/io/importdata.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/io/importdata.m	Wed Nov 18 15:48:27 2015 -0800
@@ -92,7 +92,7 @@
   endif
 
   ## Check file format
-  ## Get the extension from the file name.
+  ## Get the extension from the filename.
   [~, ~, ext, ~] = fileparts (fname);
   ext = lower (ext);
 
--- a/scripts/miscellaneous/copyfile.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/miscellaneous/copyfile.m	Wed Nov 18 15:48:27 2015 -0800
@@ -22,7 +22,7 @@
 ## Copy the source files or directories @var{f1} to the destination @var{f2}.
 ##
 ## The name @var{f1} may contain globbing patterns.  If @var{f1} expands to
-## multiple file names, @var{f2} must be a directory.
+## multiple filenames, @var{f2} must be a directory.
 ##
 ## When the force flag @qcode{'f'} is given any existing files will be
 ## overwritten without prompting.
@@ -79,7 +79,7 @@
     error ("copyfile: when copying multiple files, F2 must be a directory");
   endif
 
-  ## Protect the file name(s).
+  ## Protect the filename(s).
   f1 = glob (f1);
   if (isempty (f1))
     error ("copyfile: no files to move");
--- a/scripts/miscellaneous/edit.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/miscellaneous/edit.m	Wed Nov 18 15:48:27 2015 -0800
@@ -139,7 +139,7 @@
   FUNCTION.EDITOR = [EDITOR() " %s"];
 
   if (nargin == 1)
-    ## User has supplied one arg, this can be a single file name
+    ## User has supplied one arg, this can be a single filename
     ## or a cell array of strings containing multiple files to be opened
     if (iscellstr (varargin{1}))
       ## If first arg is a cell array of strings,
@@ -153,7 +153,7 @@
       error ("edit: file NAME must be a string or cell array of strings");
     endif
   elseif (nargin == 2)
-    ## User has supplied two arguments, these could be two file names,
+    ## User has supplied two arguments, these could be two filenames,
     ## or a combination of editor state name and new value for that state,
     ## so first check for the various states
     statevar = varargin{1};
@@ -206,7 +206,7 @@
         return;
       otherwise
         ## If none of the states match, assume both inputs are actually
-        ## file names to be opened.
+        ## filenames to be opened.
         editfilelist = varargin;
     endswitch
   elseif (nargin > 2)
@@ -242,7 +242,7 @@
 
   else
 
-    ## Only one file name was supplied, get it from the cell array
+    ## Only one filename was supplied, get it from the cell array
     file = tilde_expand (editfilelist{1});
 
     ## Check whether the user is trying to edit a builtin or compiled function.
@@ -269,7 +269,7 @@
     ## The code below includes a portion that serves as a place-holder for
     ## the changes suggested above.
 
-    ## Create list of explicit and implicit file names.
+    ## Create list of explicit and implicit filenames.
     filelist = {file};
     ## If file has no extension, add file.m and file.cc to the list.
     idx = rindex (file, ".");
--- a/scripts/miscellaneous/mkoctfile.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/miscellaneous/mkoctfile.m	Wed Nov 18 15:48:27 2015 -0800
@@ -31,7 +31,7 @@
 ## the exit status in the @var{status} variable.
 ##
 ## @code{mkoctfile} accepts the following options, all of which are optional
-## except for the file name of the code you wish to compile:
+## except for the filename of the code you wish to compile:
 ##
 ## @table @samp
 ## @item -I DIR
@@ -69,7 +69,7 @@
 ##
 ## @item  -o FILE
 ## @itemx --output FILE
-## Output file name.  Default extension is .oct (or .mex if @samp{--mex} is
+## Output filename.  Default extension is .oct (or .mex if @samp{--mex} is
 ## specified) unless linking a stand-alone executable.
 ##
 ## @item  -p VAR
--- a/scripts/miscellaneous/movefile.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/miscellaneous/movefile.m	Wed Nov 18 15:48:27 2015 -0800
@@ -24,9 +24,9 @@
 ## Move the source files or directories @var{f1} to the destination @var{f2}.
 ##
 ## The name @var{f1} may contain globbing patterns.  If @var{f1} expands to
-## multiple file names, @var{f2} must be a directory.  If no destination
+## multiple filenames, @var{f2} must be a directory.  If no destination
 ## @var{f2} is specified then the destination is the present working directory.
-## If @var{f2} is a file name then @var{f1} is renamed to @var{f2}.
+## If @var{f2} is a filename then @var{f1} is renamed to @var{f2}.
 ##
 ## When the force flag @qcode{'f'} is given any existing files will be
 ## overwritten without prompting.
@@ -86,7 +86,7 @@
     error ("movefile: when moving multiple files, F2 must be a directory");
   endif
 
-  ## Protect the file name(s).
+  ## Protect the filename(s).
   f1 = glob (f1);
   if (isempty (f1))
     error ("movefile: no files to move");
--- a/scripts/miscellaneous/open.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/miscellaneous/open.m	Wed Nov 18 15:48:27 2015 -0800
@@ -20,7 +20,7 @@
 ## @deftypefn  {Function File} {@var{output} =} open @var{file}
 ## @deftypefnx {Function File} {@var{output} =} open (@var{file})
 ## Open the file @var{file} in Octave or in an external application based on
-## the file type as determined by the file name extension.
+## the file type as determined by the filename extension.
 ##
 ## Recognized file types are
 ##
--- a/scripts/miscellaneous/perl.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/miscellaneous/perl.m	Wed Nov 18 15:48:27 2015 -0800
@@ -24,7 +24,7 @@
 ## arguments.
 ##
 ## Return output in @var{output} and optional status in @var{status}.  If
-## @var{scriptfile} is not an absolute file name it is searched for in the
+## @var{scriptfile} is not an absolute filename it is searched for in the
 ## current directory and then in the Octave loadpath.
 ## @seealso{system, python}
 ## @end deftypefn
--- a/scripts/miscellaneous/python.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/miscellaneous/python.m	Wed Nov 18 15:48:27 2015 -0800
@@ -25,7 +25,7 @@
 ## arguments.
 ##
 ## Return output in @var{output} and optional status in @var{status}.  If
-## @var{scriptfile} is not an absolute file name it is searched for in the
+## @var{scriptfile} is not an absolute filename it is searched for in the
 ## current directory and then in the Octave loadpath.
 ## @seealso{system, perl}
 ## @end deftypefn
--- a/scripts/miscellaneous/run.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/miscellaneous/run.m	Wed Nov 18 15:48:27 2015 -0800
@@ -25,7 +25,7 @@
 ## which end with the extension @file{".m"}, can be run simply by typing
 ## their name.  For scripts not located on the load path, use @code{run}.
 ##
-## The file name @var{script} can be a bare, fully qualified, or relative
+## The filename @var{script} can be a bare, fully qualified, or relative
 ## filename and with or without a file extension.  If no extension is specified,
 ## Octave will first search for a script with the @file{".m"} extension before
 ## falling back to the script name without an extension.
--- a/scripts/miscellaneous/tmpnam.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/miscellaneous/tmpnam.m	Wed Nov 18 15:48:27 2015 -0800
@@ -20,7 +20,7 @@
 ## @deftypefn  {Function File} {@var{fname} =} tmpnam ()
 ## @deftypefnx {Function File} {@var{fname} =} tmpnam (@var{dir})
 ## @deftypefnx {Function File} {@var{fname} =} tmpnam (@var{dir}, @var{prefix})
-## Return a unique temporary file name as a string.
+## Return a unique temporary filename as a string.
 ##
 ## If @var{prefix} is omitted, a value of @qcode{"oct-"} is used.
 ##
--- a/scripts/miscellaneous/unpack.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/miscellaneous/unpack.m	Wed Nov 18 15:48:27 2015 -0800
@@ -296,7 +296,7 @@
   ## Parse the output from bzip2 and bunzip2 returning the files
   ## commpressed (or decompressed).
 
-  ## Strip leading blanks and .bz2 extension from file name
+  ## Strip leading blanks and .bz2 extension from filename
   files = regexprep (output, '^\s+(.*)\.bz2: .*', '$1');
 endfunction
 
--- a/scripts/optimization/fminsearch.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/optimization/fminsearch.m	Wed Nov 18 15:48:27 2015 -0800
@@ -150,7 +150,7 @@
   ## Use function to minimize, not maximize
   stopit(6) = dirn = -1;
 
-  ## File name for snapshots.
+  ## Filename for snapshots.
   savit = [];  # FIXME: expose this parameter to the outside
 
 endfunction
--- a/scripts/pkg/private/configure_make.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/pkg/private/configure_make.m	Wed Nov 18 15:48:27 2015 -0800
@@ -103,7 +103,7 @@
     instdir = fullfile (packdir, "inst");
     archdir = fullfile (packdir, "inst", getarch ());
 
-    ## Get file names.
+    ## Get filenames.
     if (exist (files, "file"))
       [fid, msg] = fopen (files, "r");
       if (fid < 0)
--- a/scripts/plot/util/print.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/plot/util/print.m	Wed Nov 18 15:48:27 2015 -0800
@@ -26,9 +26,9 @@
 ## Both output formatted for printing (PDF and PostScript), and many bitmapped
 ## and vector image formats are supported.
 ##
-## @var{filename} defines the name of the output file.  If the file name has
+## @var{filename} defines the name of the output file.  If the filename has
 ## no suffix, one is inferred from the specified device and appended to the
-## file name.  If no filename is specified, the output is sent to the
+## filename.  If no filename is specified, the output is sent to the
 ## printer.
 ##
 ## @var{h} specifies the handle of the figure to print.  If no handle is
--- a/scripts/plot/util/private/__print_parse_opts__.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/plot/util/private/__print_parse_opts__.m	Wed Nov 18 15:48:27 2015 -0800
@@ -329,14 +329,14 @@
       ## Pipe the ghostscript output
       arg_st.name = "-";
     else
-      error ("print: a file name may not specified when spooling to a printer")
+      error ("print: a filename may not specified when spooling to a printer")
     endif
     if (! any (strcmp (arg_st.devopt, gs_device_list)))
       ## Only supported ghostscript devices
       error ("print: format must be a valid Ghostscript format for spooling to a printer")
     endif
   elseif (isempty (arg_st.name))
-    error ("print: an output file name must be specified")
+    error ("print: an output filename must be specified")
   endif
 
   if (isempty (arg_st.canvas_size))
--- a/scripts/testfun/test.m	Wed Nov 18 15:44:33 2015 -0500
+++ b/scripts/testfun/test.m	Wed Nov 18 15:48:27 2015 -0800
@@ -189,7 +189,7 @@
     fprintf (__fid, "# %s test was skipped\n", __signal_skip);
     fprintf (__fid, "# %s code for the test\n\n", __signal_block);
     fprintf (__fid, "# Search for the unexpected results in the file\n");
-    fprintf (__fid, "# then page back to find the file name which caused it.\n");
+    fprintf (__fid, "# then page back to find the filename which caused it.\n");
     fprintf (__fid, "# The result may be an unexpected failure (in which\n");
     fprintf (__fid, "# case an error will be reported) or an unexpected\n");
     fprintf (__fid, "# success (in which case no error will be reported).\n");
--- a/src/main.in.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/src/main.in.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -436,7 +436,7 @@
 #if defined (HAVE_OCTAVE_GUI)
   // The Octave version number is already embedded in the
   // octave_archlibdir directory name so we don't need to append it to
-  // the octave-gui file name.
+  // the octave-gui filename.
 
   std::string file = octave_archlibdir + dir_sep_char + "octave-gui";
 #else
--- a/src/mkoctfile.in.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/src/mkoctfile.in.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -256,7 +256,7 @@
 "\n"
 "  -c, --compile           Compile, but do not link.\n"
 "\n"
-"  -o FILE, --output FILE  Output file name.  Default extension is .oct\n"
+"  -o FILE, --output FILE  Output filename.  Default extension is .oct\n"
 "                          (or .mex if --mex is specified) unless linking\n"
 "                          a stand-alone executable.\n"
 "\n"
@@ -503,7 +503,7 @@
               outputfile = arg;
             }
           else
-            std::cerr << "mkoctfile: output file name missing" << std::endl;
+            std::cerr << "mkoctfile: output filename missing" << std::endl;
         }
       else if (arg == "-p" || arg == "-print" || arg == "--print")
         {
--- a/src/module.mk	Wed Nov 18 15:44:33 2015 -0500
+++ b/src/module.mk	Wed Nov 18 15:48:27 2015 -0800
@@ -223,7 +223,7 @@
 
 .PHONY: make-version-links remove-version-links
 
-## We need these file names in the build tree because the wrapper
+## We need these filenames in the build tree because the wrapper
 ## program (main.cc) will try to invoke the versioned binaries.
 
 src/octave-cli-$(version)$(EXEEXT): src/octave-cli$(EXEEXT)
--- a/libgui/src/m-editor/file-editor-tab.cc	Wed Nov 18 15:44:33 2015 -0500
+++ b/libgui/src/m-editor/file-editor-tab.cc	Wed Nov 18 15:48:27 2015 -0800
@@ -719,7 +719,7 @@
     {
       save_file (_file_name);  // save file dialog
       if (! valid_file_name ())
-        return;   // still invalid file name: "save as" was cancelled
+        return;   // still invalid filename: "save as" was cancelled
     }
 
   QFileInfo info (_file_name);
@@ -1521,10 +1521,10 @@
   file_info = QFileInfo (file);
   file_to_save = file_info.canonicalFilePath ();
 
   // save file name after closing file as set_file_name starts watching again
   set_file_name (file_to_save);   // make absolute
 
-  // set the window title to actual file name (not modified)
+  // set the window title to actual filename (not modified)
   update_window_title (false);
 
   // files is save -> not modified
@@ -1678,7 +1678,7 @@
       int ans = QMessageBox::question (0, tr ("Octave Editor"),
          tr ("\"%1\"\n"
              "is not a valid identifier.\n\n"
-             "If you keep this file name, you will not be able to\n"
+             "If you keep this filename, you will not be able to\n"
              "call your script using its name as an Octave command.\n\n"
              "Do you want to choose another name?").arg (base_name),
           QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
@@ -1722,7 +1722,7 @@
     }
 
   // saveFileName == _file_name can not happen, because we only can get here
   // when we close a tab and _file_name is not a valid file name yet
 
   // Have editor check for conflict, delete tab after save.
   if (check_valid_identifier (saveFileName))
@@ -1521,10 +1521,10 @@
   file_to_save = file_info.canonicalFilePath ();
 
-  // save file name after closing file as set_file_name starts watching again
+  // save filename after closing file as set_file_name starts watching again
   set_file_name (file_to_save);   // make absolute
 
@@ -1722,7 +1722,7 @@
 
   // saveFileName == _file_name can not happen, because we only can get here
-  // when we close a tab and _file_name is not a valid file name yet
+  // when we close a tab and _file_name is not a valid filename yet
 
   // Have editor check for conflict, delete tab after save.